[Scummvm-cvs-logs] SF.net SVN: scummvm:[49843] scummvm/trunk

fingolfin at users.sourceforge.net fingolfin at users.sourceforge.net
Tue Jun 15 14:33:21 CEST 2010


Revision: 49843
          http://scummvm.svn.sourceforge.net/scummvm/?rev=49843&view=rev
Author:   fingolfin
Date:     2010-06-15 12:33:20 +0000 (Tue, 15 Jun 2010)

Log Message:
-----------
Fix spelling, cleanup

Modified Paths:
--------------
    scummvm/trunk/backends/fs/amigaos4/amigaos4-fs.cpp
    scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formSkins.cpp
    scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formmusic.cpp
    scummvm/trunk/backends/platform/PalmOS/Src/launcher/launch.cpp
    scummvm/trunk/backends/platform/ds/arm9/source/fat/io_nmmc.c
    scummvm/trunk/common/config-file.cpp
    scummvm/trunk/common/error.h
    scummvm/trunk/common/savefile.h
    scummvm/trunk/common/stream.cpp
    scummvm/trunk/common/system.h
    scummvm/trunk/engines/agi/keyboard.cpp
    scummvm/trunk/engines/agos/icons.cpp
    scummvm/trunk/engines/agos/vga_s2.cpp
    scummvm/trunk/engines/saga/saga.cpp
    scummvm/trunk/engines/sci/engine/kevent.cpp
    scummvm/trunk/engines/sci/engine/seg_manager.h
    scummvm/trunk/engines/sci/resource.cpp
    scummvm/trunk/engines/sci/sci.h
    scummvm/trunk/engines/scumm/verbs.h
    scummvm/trunk/graphics/scaler.h
    scummvm/trunk/graphics/video/codecs/qdm2.h
    scummvm/trunk/gui/GuiManager.h
    scummvm/trunk/gui/dialog.cpp
    scummvm/trunk/sound/decoders/adpcm.h
    scummvm/trunk/sound/decoders/flac.cpp
    scummvm/trunk/sound/decoders/flac.h
    scummvm/trunk/sound/decoders/mp3.h
    scummvm/trunk/sound/decoders/vag.h
    scummvm/trunk/sound/decoders/voc.h
    scummvm/trunk/sound/decoders/vorbis.h
    scummvm/trunk/sound/decoders/wave.h
    scummvm/trunk/sound/mods/protracker.h

Modified: scummvm/trunk/backends/fs/amigaos4/amigaos4-fs.cpp
===================================================================
--- scummvm/trunk/backends/fs/amigaos4/amigaos4-fs.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/backends/fs/amigaos4/amigaos4-fs.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -368,7 +368,7 @@
 		}
 
 		if (ERROR_NO_MORE_ENTRIES != IDOS->IoErr() ) {
-			debug(6, "An error occured during ExamineDir");
+			debug(6, "An error occurred during ExamineDir");
 			ret = false;
 		} else {
 			ret = true;

Modified: scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formSkins.cpp
===================================================================
--- scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formSkins.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formSkins.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -107,7 +107,7 @@
 	listP = (ListType *)GetObjectPtr(SkinsSkinList);
 	selected = LstGetSelection(listP);
 
-	if (bSave && selected == -1)	{	// may never occured...
+	if (bSave && selected == -1)	{	// may never occurred...
 		FrmCustomAlert(FrmWarnAlert, "You didn't select a skin.", 0, 0);
 		return;
 	}
@@ -164,7 +164,7 @@
 	listP = (ListType *)GetObjectPtr(SkinsSkinList);
 	selected = LstGetSelection(listP);
 
-	if (selected == -1)	{	// may never occured...
+	if (selected == -1)	{	// may never occurred...
 		FrmCustomAlert(FrmWarnAlert, "You didn't select a skin.", 0, 0);
 		return;
 	}
@@ -187,7 +187,7 @@
 	listP = (ListType *)GetObjectPtr(SkinsSkinList);
 	selected = LstGetSelection(listP);
 
-	if (selected == -1)	{	// may never occured...
+	if (selected == -1)	{	// may never occurred...
 		FrmCustomAlert(FrmInfoAlert, "You didn't select a skin.", 0, 0);
 		return;
 	}

Modified: scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formmusic.cpp
===================================================================
--- scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formmusic.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/backends/platform/PalmOS/Src/launcher/forms/formmusic.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -258,7 +258,7 @@
 		ogameInfoP = (GameInfoType *)MemHandleLock(recordH);
 
 		if (!ogameInfoP) {
-			FrmCustomAlert(FrmErrorAlert, "An error occured.",0,0);
+			FrmCustomAlert(FrmErrorAlert, "An error occurred.",0,0);
 			return;
 		}
 

Modified: scummvm/trunk/backends/platform/PalmOS/Src/launcher/launch.cpp
===================================================================
--- scummvm/trunk/backends/platform/PalmOS/Src/launcher/launch.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/backends/platform/PalmOS/Src/launcher/launch.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -468,7 +468,7 @@
 		return false;
 	}
 
-	// reset mode if screen rotation occured (DIA only)
+	// reset mode if screen rotation occurred (DIA only)
 	if (!direct && OPTIONS_TST(kOptCollapsible)) {
 		UInt8 mode = PalmScreenSize(0,0, &(gVars->screenFullWidth), &(gVars->screenFullHeight));
 		OPTIONS_RST(kOptModeLandscape);

Modified: scummvm/trunk/backends/platform/ds/arm9/source/fat/io_nmmc.c
===================================================================
--- scummvm/trunk/backends/platform/ds/arm9/source/fat/io_nmmc.c	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/backends/platform/ds/arm9/source/fat/io_nmmc.c	2010-06-15 12:33:20 UTC (rev 49843)
@@ -170,7 +170,7 @@
 
 	Neo_EnableMMC( true );		// Open SPI port to MMC card
 	Neo_SendMMCCommand(MMC_SEND_CSD, 0);
-	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occured
+	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occurred
 		Neo_EnableMMC( false );
 		return false;
 	}
@@ -227,14 +227,14 @@
 
 	// Set block length
 	Neo_SendMMCCommand(MMC_SET_BLOCKLEN, BYTE_PER_READ );
-	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occured
+	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occurred
 		Neo_EnableMMC( false );
 		return false;
 	}
 
 	// Check if we can use a higher SPI frequency
 	Neo_SendMMCCommand(MMC_SEND_CSD, 0);
-	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occured
+	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occurred
 		Neo_EnableMMC( false );
 		return false;
 	}
@@ -268,7 +268,7 @@
 
 	Neo_EnableMMC( true );												// Open SPI port to MMC card
 	Neo_SendMMCCommand( 25, sector );
-	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occured
+	if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{				// Make sure no errors occurred
 		Neo_EnableMMC( false );
 		return false;
 	}
@@ -318,7 +318,7 @@
 
 	while (totalSecs--) {
 		Neo_SendMMCCommand(MMC_READ_BLOCK, sector );
-		if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{			// Make sure no errors occured
+		if( Neo_CheckMMCResponse( 0x00, 0xFF ) == false )	{			// Make sure no errors occurred
 			Neo_EnableMMC( false );
 			return false;
 		}

Modified: scummvm/trunk/common/config-file.cpp
===================================================================
--- scummvm/trunk/common/config-file.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/common/config-file.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -125,7 +125,7 @@
 			if (*p == '\0')
 				error("ConfigFile::loadFromStream: missing ] in line %d", lineno);
 			else if (*p != ']')
-				error("ConfigFile::loadFromStream: Invalid character '%c' occured in section name in line %d", *p, lineno);
+				error("ConfigFile::loadFromStream: Invalid character '%c' occurred in section name in line %d", *p, lineno);
 
 			// Previous section is finished now, store it.
 			if (!section.name.empty())

Modified: scummvm/trunk/common/error.h
===================================================================
--- scummvm/trunk/common/error.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/common/error.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -44,7 +44,7 @@
  *       kPathInvalid, kPathIsInvalid, kInvalidPathError
  */
 enum Error {
-	kNoError = 0,				///< No error occured
+	kNoError = 0,				///< No error occurred
 	kInvalidPathError,			///< Engine initialization: Invalid game path was passed
 	kNoGameDataFoundError,		///< Engine initialization: No game data was found in the specified location
 	kUnsupportedGameidError,	///< Engine initialization: Gameid not supported by this (Meta)Engine

Modified: scummvm/trunk/common/savefile.h
===================================================================
--- scummvm/trunk/common/savefile.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/common/savefile.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -109,14 +109,14 @@
 	/**
 	 * Open the savefile with the specified name in the given directory for saving.
 	 * @param name	the name of the savefile
-	 * @return pointer to an OutSaveFile, or NULL if an error occured.
+	 * @return pointer to an OutSaveFile, or NULL if an error occurred.
 	 */
 	virtual OutSaveFile *openForSaving(const String &name) = 0;
 
 	/**
 	 * Open the file with the specified name in the given directory for loading.
 	 * @param name	the name of the savefile
-	 * @return pointer to an InSaveFile, or NULL if an error occured.
+	 * @return pointer to an InSaveFile, or NULL if an error occurred.
 	 */
 	virtual InSaveFile *openForLoading(const String &name) = 0;
 

Modified: scummvm/trunk/common/stream.cpp
===================================================================
--- scummvm/trunk/common/stream.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/common/stream.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -152,7 +152,7 @@
 		len++;
 	}
 
-	// We always terminate the buffer if no error occured
+	// We always terminate the buffer if no error occurred
 	*p = 0;
 	return buf;
 }

Modified: scummvm/trunk/common/system.h
===================================================================
--- scummvm/trunk/common/system.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/common/system.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -879,7 +879,7 @@
 
 	/**
 	 * Create a new mutex.
-	 * @return the newly created mutex, or 0 if an error occured.
+	 * @return the newly created mutex, or 0 if an error occurred.
 	 */
 	virtual MutexRef createMutex() = 0;
 

Modified: scummvm/trunk/engines/agi/keyboard.cpp
===================================================================
--- scummvm/trunk/engines/agi/keyboard.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/agi/keyboard.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -121,7 +121,7 @@
 		if (_game.controllers[i].keycode == key) {
 			debugC(3, kDebugLevelInput, "event %d: key press", _game.controllers[i].controller);
 			_game.controllerOccured[_game.controllers[i].controller] = true;
-			report("event AC:%i occured\n", _game.controllers[i].controller);
+			report("event AC:%i occurred\n", _game.controllers[i].controller);
 			return true;
 		}
 	}

Modified: scummvm/trunk/engines/agos/icons.cpp
===================================================================
--- scummvm/trunk/engines/agos/icons.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/agos/icons.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -448,7 +448,7 @@
 				setupIconHitArea(window, k++, xp, yp, itemRef);
 		} else {
 /*
- *	Just remember the overflow has occured
+ *	Just remember the overflow has occurred
  */
 			window->iconPtr->iconArray[icount].item = NULL;	/* END MARKINGS */
 			_iOverflow = 1;

Modified: scummvm/trunk/engines/agos/vga_s2.cpp
===================================================================
--- scummvm/trunk/engines/agos/vga_s2.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/agos/vga_s2.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -138,7 +138,7 @@
 	// This is a "play track". The original
 	// design stored the track to play if one was
 	// already in progress, so that the next time a
-	// "fill MIDI stream" event occured, the MIDI
+	// "fill MIDI stream" event occurred, the MIDI
 	// player would find the change and switch
 	// tracks. We use a different architecture that
 	// allows for an immediate response here, but

Modified: scummvm/trunk/engines/saga/saga.cpp
===================================================================
--- scummvm/trunk/engines/saga/saga.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/saga/saga.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -419,7 +419,7 @@
 		offset = scriptS.readUint16();
 		// In some rooms in IHNM, string offsets can be greater than the maximum value than a 16-bit integer can hold
 		// We detect this by checking the previous offset, and if it was bigger than the current one, an overflow
-		// occured (since the string offsets are sequential), so we're adding the missing part of the number
+		// occurred (since the string offsets are sequential), so we're adding the missing part of the number
 		// Fixes bug #1895205 - "IHNM: end game text/caption error"
 		if (prevOffset > offset)
 			offset += 65536;

Modified: scummvm/trunk/engines/sci/engine/kevent.cpp
===================================================================
--- scummvm/trunk/engines/sci/engine/seg_manager.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/sci/engine/seg_manager.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -407,7 +407,7 @@
 	 * Determines the name of an object
 	 * @param[in] pos	Location (segment, offset) of the object
 	 * @return			A name for that object, or a string describing an error
-	 * 					that occured while looking it up. The string is stored
+	 * 					that occurred while looking it up. The string is stored
 	 * 					in a static buffer and need not be freed (neither may
 	 * 					it be modified).
 	 */

Modified: scummvm/trunk/engines/sci/resource.cpp
===================================================================
--- scummvm/trunk/engines/sci/sci.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/sci/sci.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -222,7 +222,7 @@
 	 * This function must be run before script_run() is executed. Graphics data
 	 * is initialized iff s->gfx_state != NULL.
 	 * @param[in] s	The state to operate on
-	 * @return		true on success, false if an error occured.
+	 * @return		true on success, false if an error occurred.
 	 */
 	bool initGame();
 

Modified: scummvm/trunk/engines/scumm/verbs.h
===================================================================
--- scummvm/trunk/engines/scumm/verbs.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/scumm/verbs.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -31,7 +31,7 @@
 namespace Scumm {
 
 /**
- * The area in which some click (or key press) occured and which is passed
+ * The area in which some click (or key press) occurred and which is passed
  * to the input script.
  */
 enum ClickArea {

Modified: scummvm/trunk/graphics/scaler.h
===================================================================
--- scummvm/trunk/graphics/scaler.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/graphics/scaler.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -77,7 +77,7 @@
  * Creates a thumbnail from the current screen (without overlay).
  *
  * @param surf	a surface (will always have 16 bpp after this for now)
- * @return		false if a error occured
+ * @return		false if a error occurred
  */
 extern bool createThumbnailFromScreen(Graphics::Surface *surf);
 

Modified: scummvm/trunk/graphics/video/codecs/qdm2.h
===================================================================
--- scummvm/trunk/graphics/video/codecs/qdm2.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/graphics/video/codecs/qdm2.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -44,7 +44,7 @@
  *
  * @param stream       the SeekableReadStream from which to read the FLAC data
  * @param extraData    the QuickTime extra data stream
- * @return   a new AudioStream, or NULL, if an error occured
+ * @return   a new AudioStream, or NULL, if an error occurred
  */
 Audio::AudioStream *makeQDM2Stream(Common::SeekableReadStream *stream, Common::SeekableReadStream *extraData);
 

Modified: scummvm/trunk/gui/GuiManager.h
===================================================================
--- scummvm/trunk/gui/GuiManager.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/gui/GuiManager.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -122,7 +122,7 @@
 
 	// position and time of last mouse click (used to detect double clicks)
 	struct {
-		int16 x, y;	// Position of mouse when the click occured
+		int16 x, y;	// Position of mouse when the click occurred
 		uint32 time;	// Time
 		int count;	// How often was it already pressed?
 	} _lastClick;

Modified: scummvm/trunk/gui/dialog.cpp
===================================================================
--- scummvm/trunk/gui/dialog.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/gui/dialog.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -171,7 +171,7 @@
 	if (w && !(w->getFlags() & WIDGET_IGNORE_DRAG))
 		_dragWidget = w;
 
-	// If the click occured inside a widget which is not the currently
+	// If the click occurred inside a widget which is not the currently
 	// focused one, change the focus to that widget.
 	if (w && w != _focusedWidget && w->wantsFocus()) {
 		setFocusWidget(w);

Modified: scummvm/trunk/sound/decoders/adpcm.h
===================================================================
--- scummvm/trunk/sound/decoders/adpcm.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/adpcm.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -71,7 +71,7 @@
  * @param rate              the sampling rate
  * @param channels          the number of channels
  * @param blockAlign        block alignment ???
- * @return   a new RewindableAudioStream, or NULL, if an error occured
+ * @return   a new RewindableAudioStream, or NULL, if an error occurred
  */
 RewindableAudioStream *makeADPCMStream(
     Common::SeekableReadStream *stream,

Modified: scummvm/trunk/sound/decoders/flac.cpp
===================================================================
--- scummvm/trunk/sound/decoders/flac.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/flac.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -41,8 +41,8 @@
 #ifndef SOUND_FLAC_H
 #define SOUND_FLAC_H
 
+#include "common/scummsys.h"
 #include "common/types.h"
-#include "common/scummsys.h"
 
 #ifdef USE_FLAC
 
@@ -61,7 +61,7 @@
  *
  * @param stream            the SeekableReadStream from which to read the FLAC data
  * @param disposeAfterUse   whether to delete the stream after use
- * @return   a new SeekableAudioStream, or NULL, if an error occured
+ * @return   a new SeekableAudioStream, or NULL, if an error occurred
  */
 SeekableAudioStream *makeFLACStream(
 	Common::SeekableReadStream *stream,

Modified: scummvm/trunk/sound/decoders/mp3.h
===================================================================
--- scummvm/trunk/sound/decoders/mp3.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/mp3.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -41,8 +41,8 @@
 #ifndef SOUND_MP3_H
 #define SOUND_MP3_H
 
+#include "common/scummsys.h"
 #include "common/types.h"
-#include "common/scummsys.h"
 
 #ifdef USE_MAD
 
@@ -61,7 +61,7 @@
  *
  * @param stream			the SeekableReadStream from which to read the MP3 data
  * @param disposeAfterUse	whether to delete the stream after use
- * @return	a new SeekableAudioStream, or NULL, if an error occured
+ * @return	a new SeekableAudioStream, or NULL, if an error occurred
  */
 SeekableAudioStream *makeMP3Stream(
 	Common::SeekableReadStream *stream,

Modified: scummvm/trunk/sound/decoders/vag.h
===================================================================
--- scummvm/trunk/sound/decoders/vag.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/vag.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -49,7 +49,7 @@
  *
  * @param stream            the SeekableReadStream from which to read the ADPCM data
  * @param rate              the sampling rate
- * @return   a new RewindableAudioStream, or NULL, if an error occured
+ * @return   a new RewindableAudioStream, or NULL, if an error occurred
  */
 RewindableAudioStream *makeVagStream(
 	Common::SeekableReadStream *stream,

Modified: scummvm/trunk/sound/decoders/voc.h
===================================================================
--- scummvm/trunk/sound/decoders/voc.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/voc.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -38,8 +38,8 @@
 #ifndef SOUND_VOC_H
 #define SOUND_VOC_H
 
+#include "common/scummsys.h"
 #include "common/types.h"
-#include "common/scummsys.h"
 
 namespace Common { class ReadStream; }
 namespace Common { class SeekableReadStream; }

Modified: scummvm/trunk/sound/decoders/vorbis.h
===================================================================
--- scummvm/trunk/sound/decoders/vorbis.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/vorbis.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -41,8 +41,8 @@
 #ifndef SOUND_VORBIS_H
 #define SOUND_VORBIS_H
 
+#include "common/scummsys.h"
 #include "common/types.h"
-#include "common/scummsys.h"
 
 #ifdef USE_VORBIS
 
@@ -61,7 +61,7 @@
  *
  * @param stream			the SeekableReadStream from which to read the Ogg Vorbis data
  * @param disposeAfterUse	whether to delete the stream after use
- * @return	a new SeekableAudioStream, or NULL, if an error occured
+ * @return	a new SeekableAudioStream, or NULL, if an error occurred
  */
 SeekableAudioStream *makeVorbisStream(
 	Common::SeekableReadStream *stream,

Modified: scummvm/trunk/sound/decoders/wave.h
===================================================================
--- scummvm/trunk/sound/decoders/wave.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/wave.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -38,8 +38,8 @@
 #ifndef SOUND_WAVE_H
 #define SOUND_WAVE_H
 
+#include "common/scummsys.h"
 #include "common/types.h"
-#include "common/scummsys.h"
 
 namespace Common { class SeekableReadStream; }
 
@@ -71,7 +71,7 @@
  *
  * @param stream			the SeekableReadStream from which to read the WAVE data
  * @param disposeAfterUse	whether to delete the stream after use
- * @return	a new RewindableAudioStream, or NULL, if an error occured
+ * @return	a new RewindableAudioStream, or NULL, if an error occurred
  */
 RewindableAudioStream *makeWAVStream(
 	Common::SeekableReadStream *stream,

Modified: scummvm/trunk/sound/mods/protracker.h
===================================================================
--- scummvm/trunk/sound/mods/protracker.h	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/mods/protracker.h	2010-06-15 12:33:20 UTC (rev 49843)
@@ -48,7 +48,7 @@
  * @param stream	the ReadStream from which to read the ProTracker data
  * @param rate		TODO
  * @param stereo	TODO
- * @return	a new AudioStream, or NULL, if an error occured
+ * @return	a new AudioStream, or NULL, if an error occurred
  */
 AudioStream *makeProtrackerStream(Common::SeekableReadStream *stream, int offs = 0, int rate = 44100, bool stereo = true);
 


This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.




More information about the Scummvm-git-logs mailing list
--- scummvm/trunk/engines/sci/engine/kevent.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/sci/engine/kevent.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -129,9 +129,9 @@
 	if ((s->r_acc.offset) && (g_debugState.stopOnEvent)) {
 		g_debugState.stopOnEvent = false;
 
 		// A SCI event occured, and we have been asked to stop, so open the debug console
 		Console *con = g_sci->getSciDebugger();
-		con->DebugPrintf("SCI event occured: ");
+		con->DebugPrintf("SCI event occurred: ");
 		switch (curEvent.type) {
 		case SCI_EVENT_QUIT:
 			con->DebugPrintf("quit event\n");
@@ -129,9 +129,9 @@
 		g_debugState.stopOnEvent = false;
 
-		// A SCI event occured, and we have been asked to stop, so open the debug console
+		// A SCI event occurred, and we have been asked to stop, so open the debug console
 		Console *con = g_sci->getSciDebugger();

Modified: scummvm/trunk/engines/sci/engine/seg_manager.h
===================================================================
--- scummvm/trunk/engines/sci/resource.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/engines/sci/resource.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -341,7 +341,7 @@
 
 	int error = res->decompress(stream);
 	if (error) {
-		warning("Error %d occured while reading %s from Mac resource file: %s",
+		warning("Error %d occurred while reading %s from Mac resource file: %s",
 				error, res->_id.toString().c_str(), sci_error_types[error]);
 		res->unalloc();
 	}
@@ -442,7 +442,7 @@
 		delete fileStream;
 
 	if (error) {
-		warning("Error %d occured while reading %s from resource file: %s",
+		warning("Error %d occurred while reading %s from resource file: %s",
 				error, res->_id.toString().c_str(), sci_error_types[error]);
 		res->unalloc();
 	}
@@ -817,7 +817,7 @@
 		loadResource(retval);
 	else if (retval->_status == kResStatusEnqueued)
 		removeFromLRU(retval);
 	// Unless an error occured, the resource is now either
 	// locked or allocated, but never queued or freed.
 
 	freeOldResources();
@@ -817,7 +817,7 @@
 	else if (retval->_status == kResStatusEnqueued)
 		removeFromLRU(retval);
-	// Unless an error occured, the resource is now either
+	// Unless an error occurred, the resource is now either
 	// locked or allocated, but never queued or freed.
 

Modified: scummvm/trunk/engines/sci/sci.h
===================================================================
--- scummvm/trunk/sound/decoders/flac.cpp	2010-06-15 12:31:37 UTC (rev 49842)
+++ scummvm/trunk/sound/decoders/flac.cpp	2010-06-15 12:33:20 UTC (rev 49843)
@@ -230,7 +230,7 @@
 		if (processUntilEndOfMetadata() && _streaminfo.channels > 0) {
 			_lastSample = _streaminfo.total_samples + 1;
 			_length = Timestamp(0, _lastSample - 1, getRate());
-			return; // no error occured
+			return; // no error occurred
 		}
 	}
 
@@ -355,7 +355,7 @@
 		break;
 	default:
 		decoderOk = false;
-		warning("FLACStream: An error occured while decoding. DecoderState is: %s",
+		warning("FLACStream: An error occurred while decoding. DecoderState is: %s",
 			FLAC__StreamDecoderStateString[getStreamDecoderState()]);
 	}
 
@@ -668,7 +668,7 @@
 }
 inline void FLACStream::callbackError(::FLAC__StreamDecoderErrorStatus status) {
 	// some of these are non-critical-Errors
-	debug(1, "FLACStream: An error occured while decoding. DecoderState is: %s",
+	debug(1, "FLACStream: An error occurred while decoding. DecoderState is: %s",
 			FLAC__StreamDecoderErrorStatusString[status]);
 }
 

Modified: scummvm/trunk/sound/decoders/flac.h
===================================================================